# Reading Data of Economics and Econometrics;
data <-read.table(file.choose(),sep=",",header=TRUE)
head(data)
datatable=data.frame(data)
y1=datatable$CitedBy
x_collaboration<-datatable$len_first_name
x_gini<-datatable$gini_coef

y<-log(y1+1)
yy<-y1+1


library(quantreg)

#Plot for citation counts on collaboration variable
png(file ="plot1.png", width = 5000, height = 3400, units = "px", res = 800)
plot(jitter(x_collaboration,amount = .25),jitter(y1,amount = 1),cex=.5,col="grey60",ylab = 'Citation Count', frame.plot=TRUE,xlab='Collaboration',cex.lab=.8,cex.axis=.8)
taus <- c(.05,.25,.5,.75,.9)
abline(rq(y1~ x_collaboration, tau = .25), col = "darkgreen")
abline(rq(y1 ~ x_collaboration, tau = .5), col = "blue")
abline(rq(y1 ~ x_collaboration, tau = .75), col = "black", )
abline(rq(y1 ~ x_collaboration, tau = .9), col = "red")

grid(lty = 1)
legend("topright",
       inset=.05, title = 'Quantile',
       cex =.5, 
       lty=c(1,1,1,1),  
       
       c("0.25","0.50","0.75","0.90"), 
       horiz=F,
       col=c("darkgreen","blue","black","red"), 
       bg="grey96",
       text.font=1)
dev.off()


#Plot for citation counts on journal internationality variable
png(file ="plot2.png", width = 5000, height = 3400, units = "px", res = 800)
plot(jitter(x_gini,amount = .005),jitter(y1,amount = 15),cex=.5,col="grey60",ylab = 'Citation Count', frame.plot=TRUE,xlab='Journal Internationality',cex.lab=.8,cex.axis=.8)
taus <- c(.05,.25,.5,.75,.9)
abline(rq(y1~ x_gini, tau = .25), col = "darkgreen")
abline(rq(y1 ~ x_gini, tau = .5), col = "blue")
abline(rq(y1 ~ x_gini, tau = .75), col = "black", )
abline(rq(y1 ~ x_gini, tau = .9), col = "red")


grid(lty = 1)
legend("topright",
       inset=.05, title = 'Quantile',
       cex =.5, 
       lty=c(1,1,1,1),  
       
       c("0.25","0.50","0.75","0.90"), 
       horiz=F,
       col=c("darkgreen","blue","black","red"), 
       bg="grey96",
       text.font=1)
dev.off()


################################################################################


#Plot for engel data
data(engel)
png(file ="plot3.png", width = 5000, height = 3400, units = "px", res = 800)
plot(engel$income,engel$foodexp,cex=.5,col="blue",ylab = 'Food Expenditure', frame.plot=TRUE,xlab='Household Income',cex.lab=.8,cex.axis=.8)
m1 <- lm(engel$foodexp ~ engel$income)
abline(m1, col = "red",cex=.5,lty = 2)
taus <- c(.05,.25,.5,.75,.95)
abline(rq(engel$foodexp ~ engel$income, tau = .25), col = "darkgreen")
abline(rq(engel$foodexp ~ engel$income, tau = .5), col = "blue")
abline(rq(engel$foodexp ~engel$income, tau = .75), col = "black", )
abline(rq(engel$foodexp ~engel$income, tau = .95), col = "grey", )
# abline(rq(y ~ x1, tau = .9), col = "blue",lty=2,  lwd=1)

grid(lty = 1)
legend("bottomright",
       inset=.05, title = 'Quantile',
       cex =.5, 
       lty=c(1,1,1,1,2),  
       
       c("0.25","0.50","0.75","0.95","OLS"), 
       horiz=F,
       col=c("darkgreen","blue","black","grey","red"), 
       bg="grey96",
       text.font=1)
dev.off()









################################################################################
# Modeling the mu parameter of zero modified descrete lognoemal
  
    alogit<-function(t) exp(t)/(1+exp((t)))
    identity<-function(t) (t)
    plink<-function(t) identity(t)
    mulink<-function(t) (t)
    slink<-function(t) (t)
    
    
    check.integer <- function(t) {
      t == round(t)
    }
    
    
    #modeling parameter mu in ZMDLN for log(citation coount+1) on journal internationality
    ddlnorm=function(mu,sigma,yres) 
      ifelse( (check.integer(yres)&yres>=1)==TRUE,(plnorm(yres+1/2,mu,sigma)-plnorm(yres-1/2,mu,sigma))/(1-plnorm(1/2,mu,sigma)),0)
    
    dzdlnorm2<-function(p0,mu0,mu1,sigma,yres) 
      ifelse(yres==1, plink(p0)+plink(1-(p0))*ddlnorm(mulink(mu0+mu1*x_gini),slink(sigma),yres),plink(1-(p0))*ddlnorm(mulink(mu0+mu1*x_gini),slink(sigma),yres))
    
    fun2 = function(p0,mu0,mu1,sigma,yres) dzdlnorm2(p0,mu0,mu1,sigma,yres)
    fun2b = function(x, yres) sum(log(fun2(x[1], x[2],x[3],x[4],yres)))
    
    rm(zmdln2)
    zmdln2 = optim(c(0,0,0.4,1.5),fun2b,control=list(fnscale=-1,maxit=100000),y=yy,hessian=TRUE) 
    zmdln2
    
    
    # standard error of parameters
    SEP0<-round(sqrt(diag(solve(-zmdln2$hessian)))[1],4) 
    SEMU0<-round(sqrt(diag(solve(-zmdln2$hessian)))[2],4) 
    
    SEMU1<-round(sqrt(diag(solve(-zmdln2$hessian)))[3],4)
    
    SESIGMA<-round(sqrt(diag(solve(-zmdln2$hessian)))[4],4)
    
    
    # estimation of parameters
    P0<-round(zmdln2$par[1],3)  
    MU0<-round(zmdln2$par[2],3) 
    MU1<-round(zmdln2$par[3],2)
    SIGMA<-round(zmdln2$par[4],2)
    LLZMDLN_new_density<-round(zmdln2$value,2)
    AIC<-2-2*(LLZMDLN_new_density)
    
    
    
    #Confidence Interval (95%)
    CIMU1L<-round(MU1-(1.96* SEMU1),3)
    CIMU1U<-round(MU1+(1.96* SEMU1),3)
    
    CISIGMAL<-round(SIGMA-(1.96*SESIGMA),3)
    CISIGMAU<-round(SIGMA+(1.96*SESIGMA),3)
    
    CIMU0L<-round(MU0-(1.96*SEMU0),3)
    CIMU0U<-round(MU0+(1.96*SEMU0),3)
    
    
    CIP0L<-round(P0-(1.96*SEP0),3)
    CIP0U<-round(P0+(1.96*SEP0),3)
    #Wald Test (two-tailed P_value)
    
    pvalue_mu0<-round(2*pnorm(-abs((MU0-0)/SEMU0)),5)           #for MU (H0: MU=0)
    pvalue_mu1<-round(2*pnorm(-abs((MU1-0)/SEMU1)),5)  
    pvalue_sigma<-round(2*pnorm(-abs((SIGMA-1)/SESIGMA)),5)  #for SIGMA (H0: SIGMA=1)
    pvalue_p0<-round(2*pnorm(-abs((P0-0)/SEP0)),5)            #for P (H0: P=0)
   
    
    
    #modeling parameter mu in ZMDLN for log(citation coount+1) on collaboration
  
      ddlnorm=function(mu,sigma,yres) 
      ifelse( (check.integer(yres)&yres>=1)==TRUE,(plnorm(yres+1/2,mu,sigma)-plnorm(yres-1/2,mu,sigma))/(1-plnorm(1/2,mu,sigma)),0)
    
    dzdlnorm2<-function(p0,mu0,mu1,sigma,yres) 
      ifelse(yres==1, plink(p0)+plink(1-(p0))*ddlnorm(mulink(mu0+mu1*x_collaboration),slink(sigma),yres),plink(1-(p0))*ddlnorm(mulink(mu0+mu1*x_collaboration),slink(sigma),yres))
    
    fun2 = function(p0,mu0,mu1,sigma,yres) dzdlnorm2(p0,mu0,mu1,sigma,yres)
    fun2b = function(x, yres) sum(log(fun2(x[1], x[2],x[3],x[4],yres)))
    
    rm(zmdln2)
    zmdln2 = optim(c(0,0,0.4,1.5),fun2b,control=list(fnscale=-1,maxit=100000),y=yy,hessian=TRUE) 
    zmdln2
    
    
    # standard error of parameters
    SEP0<-round(sqrt(diag(solve(-zmdln2$hessian)))[1],4) 
    SEMU0<-round(sqrt(diag(solve(-zmdln2$hessian)))[2],4) 
    
    SEMU1<-round(sqrt(diag(solve(-zmdln2$hessian)))[3],4)
    
    SESIGMA<-round(sqrt(diag(solve(-zmdln2$hessian)))[4],4)
    
    
    # estimation of parameters
    P0<-round(zmdln2$par[1],3)  
    MU0<-round(zmdln2$par[2],3) 
    MU1<-round(zmdln2$par[3],2)
    SIGMA<-round(zmdln2$par[4],2)
    LLZMDLN_new_density<-round(zmdln2$value,2)
    AIC<-2-2*(LLZMDLN_new_density)
    
    
    
    #Confidence Interval (95%)
    CIMU1L<-round(MU1-(1.96* SEMU1),3)
    CIMU1U<-round(MU1+(1.96* SEMU1),3)
    
    CISIGMAL<-round(SIGMA-(1.96*SESIGMA),3)
    CISIGMAU<-round(SIGMA+(1.96*SESIGMA),3)
    
    CIMU0L<-round(MU0-(1.96*SEMU0),3)
    CIMU0U<-round(MU0+(1.96*SEMU0),3)
    
    
    CIP0L<-round(P0-(1.96*SEP0),3)
    CIP0U<-round(P0+(1.96*SEP0),3)
    #Wald Test (two-tailed P_value)
    
    pvalue_mu0<-round(2*pnorm(-abs((MU0-0)/SEMU0)),5)           #for MU (H0: MU=0)
    pvalue_mu1<-round(2*pnorm(-abs((MU1-0)/SEMU1)),5)  
    pvalue_sigma<-round(2*pnorm(-abs((SIGMA-1)/SESIGMA)),5)  #for SIGMA (H0: SIGMA=1)
    pvalue_p0<-round(2*pnorm(-abs((P0-0)/SEP0)),5)            #for P (H0: P=0)
    
    
    
    
    
    
    